@@ -1,7 +1,6 @@
-# coding: utf-8
 from django.contrib.auth import login, logout
-from django.core.urlresolvers import reverse_lazy
 from django.shortcuts import redirect
+from django.urls import reverse_lazy
 from django.views.generic import FormView, RedirectView
 
 from .forms import LoginForm
