@@ -1,8 +1,8 @@
-# coding: utf-8
+from dartcms.views import (DeleteObjectView, GridView, InsertObjectView,
+                           UpdateObjectView)
 from django.conf.urls import url
 
-from dartcms.views import GridView, InsertObjectView, UpdateObjectView, DeleteObjectView
-
+app_name = 'dicts'
 
 urlpatterns = [
     url(r'^$', GridView.as_view(search=['name']), name='index'),
