@@ -1,4 +1,3 @@
-# coding: utf-8
 from django.conf.urls import url
 from django.contrib.auth.decorators import login_required
 
@@ -6,6 +5,8 @@ from .views import (CreateFolderView, DeleteFileView, DeleteFolderView,
                     FileManagerIndexView, GetFilesView, GetTreeView,
                     RenameFolderView, UploadFileView)
 
+app_name = 'filemanager'
+
 urlpatterns = [
     url(r'^$', login_required(FileManagerIndexView.as_view()), name='index'),
     url(r'^get-tree/$', login_required(GetTreeView.as_view()), name='get_tree'),
