@@ -1,7 +1,6 @@
-# coding: utf-8
 from django.contrib import admin
 
-from models import Module, ModuleGroup
+from .models import Module, ModuleGroup, ModulePermission
 
 
 class ModuleGroupAdmin(admin.ModelAdmin):
@@ -16,3 +15,10 @@ class ModuleAdmin(admin.ModelAdmin):
 
 
 admin.site.register(Module, ModuleAdmin)
+
+
+class ModulePermissionAdmin(admin.ModelAdmin):
+    pass
+
+
+admin.site.register(ModulePermission, ModulePermissionAdmin)
