@@ -1,7 +1,6 @@
-# coding: utf-8
-from django.core.urlresolvers import reverse, NoReverseMatch
+from django.urls import NoReverseMatch, reverse
 
-from .models import Module
+from .models import Module, ModulePermission
 
 
 def get_current_module(path):
@@ -15,4 +14,10 @@ def get_current_module(path):
         try:
             return Module.objects.get(slug=module_slug)
         except Module.DoesNotExist:
-            pass
\ No newline at end of file
+            pass
+
+
+def get_current_module_perms(request):
+    cms_module = get_current_module(request.path)
+    if cms_module:
+        return ModulePermission.objects.filter(user=request.user, module=cms_module).first()
